/*
 * Copyright (C) 2019  CZ.NIC, z. s. p. o.
 *
 * This file is part of FRED.
 *
 * FRED is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * FRED is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with FRED.  If not, see <https://www.gnu.org/licenses/>.
 */
#ifndef GET_LOG_ENTRY_HH_5908539F69744E328FA8A444800172E3
#define GET_LOG_ENTRY_HH_5908539F69744E328FA8A444800172E3

#include "src/log_entry_ident.hh"

#include <boost/date_time/posix_time/posix_time.hpp>
#include <boost/optional/optional.hpp>

#include <string>
#include <vector>

namespace Fred {
namespace Logger {

struct GetLogEntryInfoRequest
{
    LogEntryIdent log_entry_ident;
};

struct LogEntryPropertyChildren
{
    std::string property_type;
    std::string property_value;
};

struct LogEntryProperty
{
    std::string property_value;
    std::vector<LogEntryPropertyChildren> children;
};

struct LogEntryProperties
{
    std::string property_type;
    std::vector<LogEntryProperty> properties;
};

struct ObjectReferences
{
    std::string object_type;
    std::vector<std::string> object_reference_ids;
};

struct LogEntryInfo
{
    boost::posix_time::ptime time_begin;
    boost::posix_time::ptime time_end;
    std::string service_name;
    boost::optional<std::string> source_ip;
    boost::optional<std::string> log_entry_type;
    boost::optional<unsigned long long> result_code;
    boost::optional<std::string> result_name;
    boost::optional<std::string> raw_request;
    boost::optional<std::string> raw_response;
    boost::optional<std::string> username;
    boost::optional<unsigned long long> user_id;
    std::vector<LogEntryProperties> log_entry_properties;
    std::vector<ObjectReferences> object_references;
};

struct GetLogEntryInfoReply
{
    LogEntryInfo log_entry_info;
};

GetLogEntryInfoReply get_log_entry(const GetLogEntryInfoRequest& _request);

} // namespace Fred::Logger
} // namespace Fred

#endif
