/*
 * Copyright (C) 2019  CZ.NIC, z. s. p. o.
 *
 * This file is part of FRED.
 *
 * FRED is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * FRED is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with FRED.  If not, see <https://www.gnu.org/licenses/>.
 */
#include "src/exceptions.hh"
#include "src/util.hh"

#include "util/db/query_param.hh"

namespace Fred {
namespace Logger {

unsigned long long get_service_id_by_name(LibFred::OperationContext& _ctx, const std::string& _service_name)
{
    const Database::Result db_result = _ctx.get_conn().exec_params(
          // clang-format off
          "SELECT id FROM service WHERE name = $1::text",
          // clang-format on
          Database::query_param_list(_service_name));
    if (db_result.size() != 1)
    {
        throw ServiceNotFound();
    }
    const auto service_id = static_cast<unsigned long long>(db_result[0][0]);
    return service_id;
}

} // namespace Fred::Logger
} // namespace Fred
